@@ -52,7 +52,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:POINTER (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:1) */
+/* BOOLEAN:POINTER (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:1) */
 void
 midori_cclosure_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                           GValue       *return_value G_GNUC_UNUSED,
@@ -64,9 +64,9 @@ midori_cclosure_marshal_BOOLEAN__POINTER (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
                                                      gpointer     arg_1,
                                                      gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -91,7 +91,7 @@ midori_cclosure_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:2) */
+/* BOOLEAN:OBJECT (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:2) */
 void
 midori_cclosure_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                          GValue       *return_value G_GNUC_UNUSED,
@@ -103,9 +103,9 @@ midori_cclosure_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -130,7 +130,7 @@ midori_cclosure_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:3) */
+/* BOOLEAN:OBJECT,OBJECT (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:3) */
 void
 midori_cclosure_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value G_GNUC_UNUSED,
@@ -143,9 +143,9 @@ midori_cclosure_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                            gpointer     arg_1,
                                                            gpointer     arg_2,
                                                            gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -171,7 +171,7 @@ midori_cclosure_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT,POINTER (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:4) */
+/* BOOLEAN:OBJECT,OBJECT,POINTER (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:4) */
 void
 midori_cclosure_marshal_BOOLEAN__OBJECT_OBJECT_POINTER (GClosure     *closure,
                                                         GValue       *return_value G_GNUC_UNUSED,
@@ -185,9 +185,9 @@ midori_cclosure_marshal_BOOLEAN__OBJECT_OBJECT_POINTER (GClosure     *closure,
                                                                    gpointer     arg_2,
                                                                    gpointer     arg_3,
                                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -214,7 +214,7 @@ midori_cclosure_marshal_BOOLEAN__OBJECT_OBJECT_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:5) */
+/* BOOLEAN:VOID (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:5) */
 void
 midori_cclosure_marshal_BOOLEAN__VOID (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -225,9 +225,9 @@ midori_cclosure_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -251,7 +251,7 @@ midori_cclosure_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:6) */
+/* BOOLEAN:STRING (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:6) */
 void
 midori_cclosure_marshal_BOOLEAN__STRING (GClosure     *closure,
                                          GValue       *return_value G_GNUC_UNUSED,
@@ -263,9 +263,9 @@ midori_cclosure_marshal_BOOLEAN__STRING (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__STRING) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -290,7 +290,7 @@ midori_cclosure_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:OBJECT (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:7) */
+/* OBJECT:OBJECT (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:7) */
 void
 midori_cclosure_marshal_OBJECT__OBJECT (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -302,9 +302,9 @@ midori_cclosure_marshal_OBJECT__OBJECT (GClosure     *closure,
   typedef GObject* (*GMarshalFunc_OBJECT__OBJECT) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_OBJECT__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -329,7 +329,7 @@ midori_cclosure_marshal_OBJECT__OBJECT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* VOID:BOOLEAN,STRING (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:8) */
+/* VOID:BOOLEAN,STRING (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:8) */
 void
 midori_cclosure_marshal_VOID__BOOLEAN_STRING (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -342,9 +342,9 @@ midori_cclosure_marshal_VOID__BOOLEAN_STRING (GClosure     *closure,
                                                      gboolean     arg_1,
                                                      gpointer     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__BOOLEAN_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -366,7 +366,7 @@ midori_cclosure_marshal_VOID__BOOLEAN_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,ENUM,BOOLEAN (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:9) */
+/* VOID:OBJECT,ENUM,BOOLEAN (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:9) */
 void
 midori_cclosure_marshal_VOID__OBJECT_ENUM_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value G_GNUC_UNUSED,
@@ -380,9 +380,9 @@ midori_cclosure_marshal_VOID__OBJECT_ENUM_BOOLEAN (GClosure     *closure,
                                                           gint         arg_2,
                                                           gboolean     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_ENUM_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_ENUM_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -405,7 +405,7 @@ midori_cclosure_marshal_VOID__OBJECT_ENUM_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:10) */
+/* VOID:OBJECT,INT,INT (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:10) */
 void
 midori_cclosure_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -419,9 +419,9 @@ midori_cclosure_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                                      gint         arg_2,
                                                      gint         arg_3,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -444,7 +444,7 @@ midori_cclosure_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:11) */
+/* VOID:OBJECT,OBJECT (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:11) */
 void
 midori_cclosure_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value G_GNUC_UNUSED,
@@ -457,9 +457,9 @@ midori_cclosure_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -481,7 +481,7 @@ midori_cclosure_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:12) */
+/* VOID:POINTER,INT (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:12) */
 void
 midori_cclosure_marshal_VOID__POINTER_INT (GClosure     *closure,
                                            GValue       *return_value G_GNUC_UNUSED,
@@ -494,9 +494,9 @@ midori_cclosure_marshal_VOID__POINTER_INT (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   gint         arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -518,7 +518,7 @@ midori_cclosure_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,BOOLEAN (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:13) */
+/* VOID:STRING,BOOLEAN (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:13) */
 void
 midori_cclosure_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -531,9 +531,9 @@ midori_cclosure_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__STRING_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -555,7 +555,7 @@ midori_cclosure_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT,STRING (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:14) */
+/* VOID:STRING,INT,STRING (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:14) */
 void
 midori_cclosure_marshal_VOID__STRING_INT_STRING (GClosure     *closure,
                                                  GValue       *return_value G_GNUC_UNUSED,
@@ -569,9 +569,9 @@ midori_cclosure_marshal_VOID__STRING_INT_STRING (GClosure     *closure,
                                                         gint         arg_2,
                                                         gpointer     arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -594,7 +594,7 @@ midori_cclosure_marshal_VOID__STRING_INT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (/usr/src/ports/midori/midori-0.5.10-1.i686/src/midori/marshal.list:15) */
+/* VOID:STRING,STRING (/usr/src/ports/midori/midori-0.5.11-1.i686/src/midori-0.5.11/midori/marshal.list:15) */
 void
 midori_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                              GValue       *return_value G_GNUC_UNUSED,
@@ -607,9 +607,9 @@ midori_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
